Learn R Programming

frheritage (version 0.1.0)

geo_cast: Cast geometries to simple types

Description

This internal helper converts multi-part geometries to their single-part equivalents: MULTIPOLYGON became POLYGON, MULTILINESTRING became LINESTRING, MULTIPOINT became POINT. If the input contains mixed types, each feature is cast individually.

Usage

geo_cast(x)

Value

An sf object with geometries cast to simple types.

Arguments

x

An sf object with geometries to cast.