Learn R Programming

frheritage (version 0.1.0)

get_heritage_layernames: Get heritage layer codes and labels

Description

This function provides a reference table mapping internal codes to explore heritage layer available datasets from French Ministry of Culture's "Atlas du Patrimoine". Optionally, it can filter the table to return only selected codes.

Usage

get_heritage_layernames(code = NULL)

Value

A data.frame with two columns:

code

Official heritage layer code (character).

label

Descriptive label (character).

Arguments

code

Optional character vector of layer codes to filter. If NULL, the full reference table is returned.

Details

The available codes and their meanings are:

  • IMDN — Domaines nationaux

  • IMMH — Immeubles classes ou inscrits

  • IMUN — Patrimoine Mondial UNESCO – Emprise surfacique des biens

  • LACR — Architecture Contemporaine Remarquable

  • PADN — Protection au titre des abords de domaines nationaux

  • PAMH — Protection au titre des abords de monuments historiques

  • PAUN — Patrimoine Mondial UNESCO – Zone tampon des biens

  • SICI — Sites classes ou inscrits

  • SIPR — Sites patrimoniaux remarquables

  • ZPPA — Zones de presomption de prescriptions archeologiques

Examples

Run this code
# Get the full table of heritage layer codes
get_heritage_layernames()

# Filter for specific codes
get_heritage_layernames(c("IMMH", "SICI"))

Run the code above in your browser using DataLab