Learn R Programming

frheritage (version 0.1.0)

ids_url_build: Build a search URL for the RSS service

Description

This internal helper constructs a URL to query for the French Ministry of Culture's "Atlas du Patrimoine" RSS service. The URL filters data using a bounding box (extent) and an INSEE department code (insee_dep).

Usage

ids_url_build(extent, insee_dep)

Value

A character string containing the full URL to query the service.

Arguments

extent

A named list with elements left, bottom, right, top defining the bounding box coordinates.

insee_dep

A character or numeric INSEE department code.