This internal helper converts multi-part geometries to their single-part
equivalents: MULTIPOLYGON became POLYGON, MULTILINESTRING became LINESTRING,
MULTIPOINT became POINT. If the input contains mixed types, each feature is
cast individually.
Usage
geo_cast(x)
Value
An sf object with geometries cast to simple types.